@@ -88,7 +88,7 @@ sub _render {
     foreach my $el (@$list) {
         if (ref($el)) {
             my $body = join('', @{$el->{body}});
-            if ($body =~ m/\\begin\{comment\}\s*;\s+noslide\s*\\end{comment}/) {
+            if ($body =~ m/\\begin\{comment\}\s*;\s+noslide\s*\\end\{comment\}/) {
                 # and remove the previous element with the chapter
                 pop @out if @out;
                 next ELEMENT;
